@@ -18,6 +18,7 @@
 #include <stdio.h>
 
 #include <kiconloader.h>
+#include <klocale.h>
 
 #include <qtimer.h>
 
@@ -26,8 +27,6 @@
 #include "misc.h"
 #include "resource.h"
 
-#define i18n(x) tr(x)
-
 Kpopup::Kpopup(int argc, char **argv)
 {
  setMinimumSize(282, 260);
