@@ -1,6 +1,6 @@
 /***************************************************************************
                           kpopup.h  -  description
-                          ------------------------
+                             -------------------
     copyright            : (C) 2000 by Torsten Henschel
     email                : henschel@fh-brandenburg.de
  ***************************************************************************/
@@ -14,55 +14,53 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef KOPUP_H
-#define KOPUP_H
+#ifndef KPOPUP_H
+#define KPOPUP_H
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <kapp.h>
+#include <kstatusbar.h>
 #include <ktmainwindow.h>
-#include <kiconloader.h>
+#include <ktoolbar.h>
 
 #include <qdatetime.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-
-#include "resource.h"
+#include <qtextview.h>
 
 class Kpopup : public KTMainWindow
 {
  Q_OBJECT
 
  public:
-         Kpopup(int argc, char **argv, QWidget* parent=0, const char *name=0);
-        ~Kpopup();
+         Kpopup(int argc, char **argv);
+         ~Kpopup();
          void AnswerPopup();
          void NewPopup();
          void SetStatusText(const char *);
 
  private slots:
                void commandCallback(int);
-               void timerDone();
+               void TimerDone();
 
  private:
          void Init();
          void InitToolbar();
          void InitStatusbar();
 
-         KIconLoader *loader;
-         KMenuBar *menu;
          KStatusBar *statusbar;
          KToolBar *toolbar;
-         QPopupMenu *file;
-         QPopupMenu *help;
-         QLabel *L_PopupText;
          QLabel *L_Label_Sender;
          QLabel *L_Sender;
          QLabel *L_Label_DateTime;
          QLabel *L_DateTime;
          QDate *Date;
+         QTextView *TV_Text;
          QTime *Time;
          QTimer *timer;
-         char *Sender;
          char *Filename;
+         char *Sender;
 };
 
 #endif
