@@ -19,6 +19,7 @@
 #include <stdio.h>
 #include <unistd.h>
 
+#include <klocale.h>
 #include <kmessagebox.h>
 
 #include <qfile.h>
@@ -26,8 +27,6 @@
 #include <make_popup.h>
 #include <misc.h>
 
-#define i18n(x) tr(x)
-
 make_Popup::make_Popup(QWidget *parent, const char *name) : KDialog(parent, name, TRUE)
 {
  hostname = (char *) malloc (30 * (sizeof(char)));
